/*
 * $$Id$$
 * 
 * Copyright (C) by Vertico Software GmbH, Karlsruhe, Germany. All rights reserved.
 * 
 * NOTICE: THIS MATERIAL IS CONSIDERED A TRADE SECRET BY VERTICO SOFTWARE. UNAUTHORIZED ACCESS, USE,
 * REPRODUCTION OR DISTRIBUTION IS PROHIBITED.
 * 
 * created on ${date} by ${user}
 * 
 * $$HeadURL$$
 * 
 * $$LastChangedDate$$ $$LastChangedBy$$ $$LastChangedRevision$$
 */
package de.starface.integration.uci.java.v30.messages.events;

import java.util.List;

import de.starface.com.rpc.annotation.RpcAsynchronous;
import de.starface.com.rpc.annotation.RpcInterface;
import de.starface.com.rpc.annotation.RpcValueTranslation;
import de.starface.integration.uci.java.v30.UciService;
import de.starface.integration.uci.java.v30.UciServices;
import de.starface.integration.uci.java.v30.types.SoftPhoneRegistrationInfo;
import de.starface.integration.uci.java.v30.ucp.messages.events.UcpPhoneEvents;

/**
 * This interface defines the phone events that can be received by a UCI client implementation in
 * order to handle phone registration.
 * 
 * @author tpfeifer
 */
@UciService(UcpPhoneEvents.SERVICE_NAME)
@RpcInterface(UcpPhoneEvents.SERVICE_NAME)
@RpcValueTranslation(version = UciServices.UCI_VERSION)
public interface UciPhoneEvents
{
	/**
	 * This event provides Information about new SoftPhone registrations thats SIP credentials has
	 * been requested by the UCI client. Another UCI client might be just about to use these
	 * credentials.
	 * 
	 * @param softPhoneRegistrationInfo
	 *        the new softPhoneRegistration {@link SoftPhoneRegistrationInfo}
	 */
	@RpcAsynchronous
	public void newSoftPhoneRegisteredEvent(SoftPhoneRegistrationInfo softPhoneRegistrationInfo);
	
	/**
	 * This event provides Information about changes of telephones of this user.
	 * 
	 * @param phones
	 *        a list of all phones of this user.
	 */
	@RpcAsynchronous
	public void phonesChangedEvent(List<String> phones);
	
	/**
	 * This event provides Information about changes of the primary phone of this user.
	 * 
	 * @param phone
	 *        the id of the primary phone
	 */
	@RpcAsynchronous
	public void primaryPhoneChangedEvent(String phone);
}
