package de.starface.integration.uci.java.v30.messages.requests;

import java.util.List;

import de.starface.com.rpc.annotation.RpcInterface;
import de.starface.com.rpc.annotation.RpcValueTranslation;
import de.starface.integration.uci.java.v30.UciService;
import de.starface.integration.uci.java.v30.UciServices;
import de.starface.integration.uci.java.v30.exceptions.UciException;
import de.starface.integration.uci.java.v30.types.FmcPhone;
import de.starface.integration.uci.java.v30.ucp.messages.requests.UcpFmcPhoneRequests;

/**
 * This interface defines the FMC phone requests provided by the UCI server.
 * 
 * @author shennlich
 */
@UciService(UcpFmcPhoneRequests.SERVICE_NAME)
@RpcInterface(UcpFmcPhoneRequests.SERVICE_NAME)
@RpcValueTranslation(version = UciServices.UCI_VERSION)
public interface UciFmcPhoneRequests
{
	/**
	 * Saving a new FMC phone or updating one. <br>
	 * For a new FMC phone, set fmcId and telephoneId to -1!<br>
	 * Devices with delay <0 will not be acceppted for saving.
	 * 
	 * @param phone
	 * @throws UciException
	 */
	public void saveFmcPhone(FmcPhone phone) throws UciException;
	
	/**
	 * Deleting an FMC phone.
	 * 
	 * @param phone
	 * @throws UciException
	 */
	public void deleteFmcPhone(FmcPhone phone) throws UciException;
	
	/**
	 * Getting all FMC phones of this user.
	 * 
	 * @throws UciException
	 */
	public List<FmcPhone> getFmcPhones() throws UciException;
}
