/*
 * Copyright (C) by STARFACE Software GmbH, Karlsruhe, Germany. All rights reserved.
 * 
 * NOTICE: THIS MATERIAL IS CONSIDERED A TRADE SECRET BY VERTICO SOFTWARE. UNAUTHORIZED ACCESS, USE,
 * REPRODUCTION OR DISTRIBUTION IS PROHIBITED.
 * 
 * created on Oct 31, 2014 by pburlov
 */
package de.starface.integration.uci.java.v30.messages.requests;

import de.starface.integration.uci.java.v30.types.GlobalLineConfiguration;
import java.util.List;

import de.starface.com.rpc.annotation.RpcInterface;
import de.starface.com.rpc.annotation.RpcValueTranslation;
import de.starface.integration.uci.java.v30.UciService;
import de.starface.integration.uci.java.v30.UciServices;
import de.starface.integration.uci.java.v30.exceptions.UciException;
import de.starface.integration.uci.java.v30.ucp.messages.requests.UcpSystemRequests;

/**
 * 
 */
@UciService(UcpSystemRequests.SERVICE_NAME)
@RpcInterface(UcpSystemRequests.SERVICE_NAME)
@RpcValueTranslation(version = UciServices.UCI_VERSION)
public interface UciSystemRequests
{
	/**
	 *
	 * @param parent NAme der Rechtegruppe. Leeren String für alle Rechte. Darf nicht null sein.
	 * @return Liste mit allen freigeschalteten Rechten (aus der Gruppe)
	 * @throws UciException
	 */
	List<String> getPermissions(String parent) throws UciException;

	/**
	 * Fragt den Server eine bestimmte lizenzierbare Funktionalitaet fuer den angemeldeten
	 * benutzer freizuschalten. Wenn es serverseitig ausreichende Lizenzen vorhanden sind dann wird
	 * die Funktion/Recht automatisch für den Benutzer aktiviert ohne dass ein Admin in dem Adminbereich
	 * es explizit freischalten muss.
	 * @param permission Rechtename, darf nicht null sein
	 * @return true wenn Funktionalitaet/Recht fuer den Benutzer jetzt freigeschaltet ist
	 * @throws UciException
	 */
	boolean requestPermission(String permission) throws UciException;
	
	GlobalLineConfiguration getGlobalLineConfiguration() throws UciException;
}
