package de.starface.integration.uci.java.v30.types;

import java.io.Serializable;

import de.starface.com.rpc.annotation.RpcValue;
import de.starface.com.rpc.annotation.RpcValueObject;
import de.starface.integration.uci.java.v30.messages.events.UciCallEvents;

/**
 * This object holds the properties of the call as returned by
 * {@link UciCallEvents#receiveCallState(Call)}.
 * 
 * @author tilmann
 */
@RpcValueObject
public class CallIdChanges implements Serializable
{
	private static final long serialVersionUID = 1L;
	
	/** The oldId of the call in form of a UUID as {@link String} */
	@RpcValue
	protected String oldId;
	
	/** The newId of the call in form of a UUID as {@link String} */
	@RpcValue
	protected String newId;
	
	/**
	 * @return the oldId
	 */
	public String getOldId()
	{
		return oldId;
	}
	
	/**
	 * @param oldId
	 *        the oldId to set
	 */
	public void setOldId(String oldId)
	{
		this.oldId = oldId;
	}
	
	/**
	 * @return the newId
	 */
	public String getNewId()
	{
		return newId;
	}
	
	/**
	 * @param newId
	 *        the newId to set
	 */
	public void setNewId(String newId)
	{
		this.newId = newId;
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString()
	{
		return "CallIdChanges [oldId=" + oldId + ", newId=" + newId + "]";
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode()
	{
		final int prime = 31;
		int result = 1;
		result = prime * result + ((newId == null) ? 0 : newId.hashCode());
		result = prime * result + ((oldId == null) ? 0 : oldId.hashCode());
		return result;
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj)
	{
		if (this == obj) return true;
		if (obj == null) return false;
		if (getClass() != obj.getClass()) return false;
		CallIdChanges other = (CallIdChanges) obj;
		if (newId == null)
		{
			if (other.newId != null) return false;
		}
		else if (!newId.equals(other.newId)) return false;
		if (oldId == null)
		{
			if (other.oldId != null) return false;
		}
		else if (!oldId.equals(other.oldId)) return false;
		return true;
	}
	
}
