/*
 * $Id: CallListEntryProperties.java 466 2011-01-18 18:25:29Z tilmann $
 * 
 * Copyright (C) by Vertico Software GmbH, Karlsruhe, Germany. All rights reserved.
 * 
 * NOTICE: THIS MATERIAL IS CONSIDERED A TRADE SECRET BY VERTICO SOFTWARE. UNAUTHORIZED ACCESS, USE,
 * REPRODUCTION OR DISTRIBUTION IS PROHIBITED.
 * 
 * created on 06.08.2009 by tilmann
 * 
 * $HeadURL:
 * http://192.168.2.8/repos/eai-uci/java/trunk/ucp/src/de/vertico/starface/integration/uci/
 * v21/CallListEntryProperties.java $
 * 
 * $LastChangedDate: 2011-01-18 19:25:29 +0100 (Di, 18 Jan 2011) $ $LastChangedBy: tilmann $
 * $LastChangedRevision: 466 $
 */
package de.starface.integration.uci.java.v30.types;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

import de.starface.com.rpc.annotation.RpcValue;
import de.starface.com.rpc.annotation.RpcValueObject;
import de.starface.integration.uci.java.v30.messages.requests.UciCallListRequests;
import de.starface.integration.uci.java.v30.values.CallListEntryDirection;
import de.starface.integration.uci.java.v30.values.CallListEntryProperties;
import de.starface.integration.uci.java.v30.values.CallListEntryResult;
import de.starface.integration.uci.java.v30.values.GroupRestriction;
import de.starface.integration.uci.java.v30.values.OrderDirection;

/**
 * This object holds the properties of the call list as returned by
 * {@link UciCallListRequests#getCallList(Date, Date, CallListEntryDirection, CallListEntryResult, String, CallListEntryProperties, OrderDirection, int, int)}
 * 
 * @author tilmann
 */
@RpcValueObject
public class CallList implements Serializable
{
	private static final long serialVersionUID = 1L;
	
	/** The entries start before this point of time */
	@RpcValue
	private Date startBefore;
	
	/** The entries start after this point of time */
	@RpcValue
	private Date startAfter;
	
	/**
	 * The entries are restricted to calls of the given {@link CallListEntryDirection}. If null is
	 * given no restriction is used.
	 */
	@RpcValue
	private CallListEntryDirection directionRestriction;
	
	/**
	 * The entries are restricted to calls of the given {@link CallListEntryResult}. If null is
	 * given no restriction is used.
	 */
	@RpcValue
	private CallListEntryResult resultRestriction;
	
	/**
	 * The entries are restricted to calls belonging to the group with the given id or to calls that
	 * do not belong to any group if {@link GroupRestriction#NON_GROUP} is given. If an empty String
	 * is given no restriction is used.
	 */
	@RpcValue
	private String groupRestriction = "";
	
	/**
	 * The entries are ordered by the given property.
	 */
	@RpcValue
	private CallListEntryProperties orderProperty;
	
	/**
	 * The entries are ordered in the given direction. This may be one of the values in
	 * {@link OrderDirection}
	 */
	@RpcValue
	private OrderDirection orderDirection;
	
	/**
	 * The offset used for the retrieval of this list regarding the given time constraints and
	 * restrictions
	 */
	@RpcValue
	private int countOffset;
	
	/**
	 * The limit used for the retrieval of this list regarding the given time constraints and
	 * restrictions
	 */
	@RpcValue
	private int countLimit;
	
	/**
	 * The total count of available entries on the server regarding the given time constraints and
	 * restrictions
	 */
	@RpcValue
	private int totalCount;
	
	/**
	 * The call list entries in this list
	 */
	@RpcValue
	private List<CallListEntry> entries;
	
	public Date getStartBefore()
	{
		return startBefore;
	}
	
	public void setStartBefore(Date startBefore)
	{
		this.startBefore = startBefore;
	}
	
	public Date getStartAfter()
	{
		return startAfter;
	}
	
	public void setStartAfter(Date startAfter)
	{
		this.startAfter = startAfter;
	}
	
	public CallListEntryDirection getDirectionRestriction()
	{
		return directionRestriction;
	}
	
	public void setDirectionRestriction(CallListEntryDirection directionRestriction)
	{
		this.directionRestriction = directionRestriction;
	}
	
	public CallListEntryResult getResultRestriction()
	{
		return resultRestriction;
	}
	
	public void setResultRestriction(CallListEntryResult resultRestriction)
	{
		this.resultRestriction = resultRestriction;
	}
	
	public CallListEntryProperties getOrderProperty()
	{
		return orderProperty;
	}
	
	public void setOrderProperty(CallListEntryProperties orderProperty)
	{
		this.orderProperty = orderProperty;
	}
	
	public OrderDirection getOrderDirection()
	{
		return orderDirection;
	}
	
	public void setOrderDirection(OrderDirection orderDirection)
	{
		this.orderDirection = orderDirection;
	}
	
	public int getCountOffset()
	{
		return countOffset;
	}
	
	public void setCountOffset(int countOffset)
	{
		this.countOffset = countOffset;
	}
	
	public int getCountLimit()
	{
		return countLimit;
	}
	
	public void setCountLimit(int countLimit)
	{
		this.countLimit = countLimit;
	}
	
	public int getTotalCount()
	{
		return totalCount;
	}
	
	public void setTotalCount(int totalCount)
	{
		this.totalCount = totalCount;
	}
	
	public List<CallListEntry> getEntries()
	{
		return entries;
	}
	
	public void setEntries(List<CallListEntry> entries)
	{
		this.entries = entries;
	}
	
	public String getGroupRestriction()
	{
		return groupRestriction;
	}
	
	public void setGroupRestriction(String groupRestriction)
	{
		this.groupRestriction = groupRestriction;
	}
	
	@Override
	public String toString()
	{
		return "CallList [startBefore=" + startBefore + ", startAfter=" + startAfter
			+ ", directionRestriction=" + directionRestriction + ", resultRestriction="
			+ resultRestriction + ", groupRestriction=" + groupRestriction + ", orderProperty="
			+ orderProperty + ", orderDirection=" + orderDirection + ", countOffset=" + countOffset
			+ ", countLimit=" + countLimit + ", totalCount=" + totalCount + ", entries=" + entries
			+ "]";
	}
	
	@Override
	public int hashCode()
	{
		final int prime = 31;
		int result = 1;
		result = prime * result + countLimit;
		result = prime * result + countOffset;
		result = prime * result
			+ ((directionRestriction == null) ? 0 : directionRestriction.hashCode());
		result = prime * result + ((entries == null) ? 0 : entries.hashCode());
		result = prime * result + ((groupRestriction == null) ? 0 : groupRestriction.hashCode());
		result = prime * result + ((orderDirection == null) ? 0 : orderDirection.hashCode());
		result = prime * result + ((orderProperty == null) ? 0 : orderProperty.hashCode());
		result = prime * result + ((resultRestriction == null) ? 0 : resultRestriction.hashCode());
		result = prime * result + ((startAfter == null) ? 0 : startAfter.hashCode());
		result = prime * result + ((startBefore == null) ? 0 : startBefore.hashCode());
		result = prime * result + totalCount;
		return result;
	}
	
	@Override
	public boolean equals(Object obj)
	{
		if (this == obj) return true;
		if (obj == null) return false;
		if (getClass() != obj.getClass()) return false;
		CallList other = (CallList) obj;
		if (countLimit != other.countLimit) return false;
		if (countOffset != other.countOffset) return false;
		if (directionRestriction != other.directionRestriction) return false;
		if (entries == null)
		{
			if (other.entries != null) return false;
		}
		else if (!entries.equals(other.entries)) return false;
		if (groupRestriction == null)
		{
			if (other.groupRestriction != null) return false;
		}
		else if (!groupRestriction.equals(other.groupRestriction)) return false;
		if (orderDirection != other.orderDirection) return false;
		if (orderProperty != other.orderProperty) return false;
		if (resultRestriction != other.resultRestriction) return false;
		if (startAfter == null)
		{
			if (other.startAfter != null) return false;
		}
		else if (!startAfter.equals(other.startAfter)) return false;
		if (startBefore == null)
		{
			if (other.startBefore != null) return false;
		}
		else if (!startBefore.equals(other.startBefore)) return false;
		if (totalCount != other.totalCount) return false;
		return true;
	}
	
}
