/*
 * $Id: CallListEntryProperties.java 482 2011-01-25 15:21:54Z tilmann $
 * 
 * Copyright (C) by Vertico Software GmbH, Karlsruhe, Germany. All rights reserved.
 * 
 * NOTICE: THIS MATERIAL IS CONSIDERED A TRADE SECRET BY VERTICO SOFTWARE. UNAUTHORIZED ACCESS, USE,
 * REPRODUCTION OR DISTRIBUTION IS PROHIBITED.
 * 
 * created on 06.08.2009 by tilmann
 * 
 * $HeadURL:
 * http://192.168.2.8/repos/eai-uci/java/trunk/ucp/src/de/vertico/starface/integration/uci/
 * v21/CallListEntryProperties.java $
 * 
 * $LastChangedDate: 2011-01-25 16:21:54 +0100 (Di, 25 Jan 2011) $ $LastChangedBy: tilmann $
 * $LastChangedRevision: 482 $
 */
package de.starface.integration.uci.java.v30.types;

import java.io.Serializable;
import java.util.Date;

import de.starface.com.rpc.annotation.RpcValue;
import de.starface.com.rpc.annotation.RpcValueObject;
import de.starface.integration.uci.java.v30.messages.events.UciCallEvents;
import de.starface.integration.uci.java.v30.messages.requests.UciCallListRequests;
import de.starface.integration.uci.java.v30.messages.requests.UciCallRequests;
import de.starface.integration.uci.java.v30.values.CallListEntryDirection;
import de.starface.integration.uci.java.v30.values.CallListEntryResult;

/**
 * This object holds the properteis of the call list entries as returned by
 * {@link UciCallListRequests#getCallList(Date, Date, CallListEntryDirection, CallListEntryResult, String, de.starface.integration.uci.java.v30.values.CallListEntryProperties, de.starface.integration.uci.java.v30.values.OrderDirection, int, int)}
 * 
 * @author tilmann
 */
@RpcValueObject
public class CallListEntry implements Serializable
{
	private static final long serialVersionUID = 1L;
	
	/**
	 * The id of the call list entry
	 * 
	 * ATTENTION: This is not the same id as used in the call functions of {@link UciCallRequests}
	 * and {@link UciCallEvents}
	 */
	@RpcValue
	private String id;
	
	/** The number that was called, if known */
	@RpcValue
	private String calledNumber = "";
	
	/** The number of the caller, if known */
	@RpcValue
	private String callerNumber = "";
	
	/** A description of the call (usually the CLIP), if known */
	@RpcValue
	private String callDescription = "";
	
	/**
	 * The start time of the call. Per default dates will be ordered newest first
	 */
	@RpcValue
	private Date startTime;
	
	/** The duration of the call in seconds */
	@RpcValue
	private int duration;
	
	/**
	 * The direction of the call
	 */
	@RpcValue
	private CallListEntryDirection direction;
	
	/**
	 * The result of the call
	 */
	@RpcValue
	private CallListEntryResult result;
	
	/**
	 * The id of a voicemail that was recorded for the call if existing (the empty string otherwise)
	 */
	@RpcValue
	private String voicemailId = "";
	
	/**
	 * The name of the group if this call was received by a group (the empty string otherwise)
	 */
	@RpcValue(minVersion = 22)
	private String groupId = "";
	
	public String getId()
	{
		return id;
	}
	
	public void setId(String id)
	{
		this.id = id;
	}
	
	public String getCalledNumber()
	{
		return calledNumber;
	}
	
	public void setCalledNumber(String calledNumber)
	{
		this.calledNumber = calledNumber;
	}
	
	public String getCallerNumber()
	{
		return callerNumber;
	}
	
	public void setCallerNumber(String callerNumber)
	{
		this.callerNumber = callerNumber;
	}
	
	public String getCallDescription()
	{
		return callDescription;
	}
	
	public void setCallDescription(String callDescription)
	{
		this.callDescription = callDescription;
	}
	
	public Date getStartTime()
	{
		return startTime;
	}
	
	public void setStartTime(Date startTime)
	{
		this.startTime = startTime;
	}
	
	public int getDuration()
	{
		return duration;
	}
	
	public void setDuration(int duration)
	{
		this.duration = duration;
	}
	
	public CallListEntryDirection getDirection()
	{
		return direction;
	}
	
	public void setDirection(CallListEntryDirection direction)
	{
		this.direction = direction;
	}
	
	public CallListEntryResult getResult()
	{
		return result;
	}
	
	public void setResult(CallListEntryResult result)
	{
		this.result = result;
	}
	
	public String getVoicemailId()
	{
		return voicemailId;
	}
	
	public void setVoicemailId(String voicemailId)
	{
		this.voicemailId = voicemailId;
	}
	
	public String getGroupId()
	{
		return groupId;
	}
	
	public void setGroupId(String groupId)
	{
		this.groupId = groupId;
	}
	
	public boolean isGroupCall()
	{
		return groupId != null && !"".equals(groupId);
	}
	
	@Override
	public String toString()
	{
		return "CallListEntry [id=" + id + ", calledNumber=" + calledNumber + ", callerNumber="
			+ callerNumber + ", callDescription=" + callDescription + ", startTime=" + startTime
			+ ", duration=" + duration + ", direction=" + direction + ", result=" + result
			+ ", voicemailId=" + voicemailId + ", groupId=" + groupId + "]";
	}
	
	@Override
	public int hashCode()
	{
		final int prime = 31;
		int result = 1;
		result = prime * result + ((callDescription == null) ? 0 : callDescription.hashCode());
		result = prime * result + ((calledNumber == null) ? 0 : calledNumber.hashCode());
		result = prime * result + ((callerNumber == null) ? 0 : callerNumber.hashCode());
		result = prime * result + ((direction == null) ? 0 : direction.hashCode());
		result = prime * result + duration;
		result = prime * result + ((groupId == null) ? 0 : groupId.hashCode());
		result = prime * result + ((id == null) ? 0 : id.hashCode());
		result = prime * result + ((this.result == null) ? 0 : this.result.hashCode());
		result = prime * result + ((startTime == null) ? 0 : startTime.hashCode());
		result = prime * result + ((voicemailId == null) ? 0 : voicemailId.hashCode());
		return result;
	}
	
	@Override
	public boolean equals(Object obj)
	{
		if (this == obj) return true;
		if (obj == null) return false;
		if (getClass() != obj.getClass()) return false;
		CallListEntry other = (CallListEntry) obj;
		if (callDescription == null)
		{
			if (other.callDescription != null) return false;
		}
		else if (!callDescription.equals(other.callDescription)) return false;
		if (calledNumber == null)
		{
			if (other.calledNumber != null) return false;
		}
		else if (!calledNumber.equals(other.calledNumber)) return false;
		if (callerNumber == null)
		{
			if (other.callerNumber != null) return false;
		}
		else if (!callerNumber.equals(other.callerNumber)) return false;
		if (direction != other.direction) return false;
		if (duration != other.duration) return false;
		if (groupId == null)
		{
			if (other.groupId != null) return false;
		}
		else if (!groupId.equals(other.groupId)) return false;
		if (id == null)
		{
			if (other.id != null) return false;
		}
		else if (!id.equals(other.id)) return false;
		if (result != other.result) return false;
		if (startTime == null)
		{
			if (other.startTime != null) return false;
		}
		else if (!startTime.equals(other.startTime)) return false;
		if (voicemailId == null)
		{
			if (other.voicemailId != null) return false;
		}
		else if (!voicemailId.equals(other.voicemailId)) return false;
		return true;
	}
	
}
