package de.starface.integration.uci.java.v30.types;

import java.io.Serializable;
import java.util.Date;

import de.starface.com.rpc.annotation.RpcValue;
import de.starface.com.rpc.annotation.RpcValueObject;
import de.starface.integration.uci.java.v30.messages.events.UciConferenceCallEvents;
import de.starface.integration.uci.java.v30.values.CallState;

/**
 * This object holds the properties of the call as returned by
 * {@link UciConferenceCallEvents#receiveConferenceCallState(ConferenceCall)}.
 * 
 * @author dirk
 */
@RpcValueObject
public class ConferenceCall implements Serializable
{
	private static final long serialVersionUID = 1L;
	
	/** The id of the call in form of a UUID as {@link String} */
	@RpcValue
	protected String id;
	
	/** The phone number of the conference participant */
	@RpcValue
	protected String number = "";
	
	/** The name of the conference participant */
	@RpcValue
	protected String name = "";
	
	/** Can the participant hear */
	@RpcValue
	protected Boolean listening = true;
	
	/** Can the participant speak */
	@RpcValue
	protected Boolean muted = false;
	
	/** Is the participant speaking */
	@RpcValue
	protected Boolean talking = false;
	
	/** Want the participant speak */
	@RpcValue
	protected Integer wantToSpeak = 0;
	
	/** Is the participant admin */
	@RpcValue
	protected Boolean admin = false;
	
	/** The state of the call */
	@RpcValue
	protected CallState state;
	
	/** The Room Identifikation Number */
	@RpcValue
	protected String roomId;
	
	/** Entered Room */
	@RpcValue
	protected Date enteredTimestamp;
	
	/** The time between now and the enteredTimestamp in milliseconds **/
	@RpcValue(minVersion = 30)
	protected long duration = 0;
	
	/** The jabber id **/
	@RpcValue(minVersion = 30)
	protected String jabberId = "";
	
	/** The avatar hash **/
	@RpcValue(minVersion = 30)
	protected String avatarHash = "";
	
	public String getId()
	{
		return id;
	}
	
	public void setId(String id)
	{
		this.id = id;
	}
	
	/**
	 * @return the number
	 */
	public String getNumber()
	{
		return number;
	}
	
	/**
	 * @param number
	 *        the number to set
	 */
	public void setNumber(String number)
	{
		this.number = number;
	}
	
	/**
	 * @return the name
	 */
	public String getName()
	{
		return name;
	}
	
	/**
	 * @param name
	 *        the name to set
	 */
	public void setName(String name)
	{
		this.name = name;
	}
	
	/**
	 * @return the wantToSpeak
	 */
	public Integer getWantToSpeak()
	{
		return wantToSpeak;
	}
	
	/**
	 * @param wantToSpeak
	 *        the wantToSpeak to set
	 */
	public void setWantToSpeak(Integer wantToSpeak)
	{
		this.wantToSpeak = wantToSpeak;
	}
	
	/**
	 * @return the admin
	 */
	public Boolean isAdmin()
	{
		return admin;
	}
	
	/**
	 * @param admin
	 *        the admin to set
	 */
	public void setAdmin(Boolean admin)
	{
		this.admin = admin;
	}
	
	/**
	 * @return the state
	 */
	public CallState getState()
	{
		return state;
	}
	
	/**
	 * @param state
	 *        the state to set
	 */
	public void setState(CallState state)
	{
		this.state = state;
	}
	
	/**
	 * @return the listening
	 */
	public Boolean isListening()
	{
		return listening;
	}
	
	/**
	 * @param listen
	 *        the listen to set
	 */
	public void setListening(Boolean listen)
	{
		this.listening = listen;
	}
	
	/**
	 * @return the mute
	 */
	public Boolean isMuted()
	{
		return muted;
	}
	
	/**
	 * @param muted
	 *        the mute to set
	 */
	public void setMuted(Boolean muted)
	{
		this.muted = muted;
	}
	
	/**
	 * @return the talking
	 */
	public Boolean isTalking()
	{
		return talking;
	}
	
	/**
	 * @param talking
	 *        the talking to set
	 */
	public void setTalking(Boolean talking)
	{
		this.talking = talking;
	}
	
	/**
	 * @return the roomId
	 */
	public String getRoomId()
	{
		return roomId;
	}
	
	/**
	 * @param roomId
	 *        the roomId to set
	 */
	public void setRoomId(String roomId)
	{
		this.roomId = roomId;
	}
	
	/**
	 * @return the enteredRoom
	 */
	public Date getEnteredTimestamp()
	{
		return enteredTimestamp;
	}
	
	/**
	 * @param enteredTimestamp
	 *        the enteredTimestamp to set
	 */
	public void setEnteredTimestamp(Date enteredTimestamp)
	{
		this.enteredTimestamp = enteredTimestamp;
	}
	
	/**
	 * @return the duration
	 */
	public long getDuration()
	{
		return duration;
	}
	
	/**
	 * @param duration
	 *        the duration to set
	 */
	public void setDuration(long duration)
	{
		this.duration = duration;
	}
	
	/**
	 * @return the jabberId
	 */
	public String getJabberId()
	{
		return jabberId;
	}
	
	/**
	 * @param jabberId
	 *        the jabberId to set
	 */
	public void setJabberId(String jabberId)
	{
		this.jabberId = jabberId;
	}
	
	/**
	 * @return the avatarHash
	 */
	public String getAvatarHash()
	{
		return avatarHash;
	}
	
	/**
	 * @param avatarHash
	 *        the avatarHash to set
	 */
	public void setAvatarHash(String avatarHash)
	{
		this.avatarHash = avatarHash;
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString()
	{
		return "ConferenceCall [id=" + id + ", number=" + number + ", name=" + name + ", listening=" + listening
			+ ", muted=" + muted + ", talking=" + talking + ", wantToSpeak=" + wantToSpeak + ", admin=" + admin
			+ ", state=" + state + ", roomId=" + roomId + ", enteredTimestamp=" + enteredTimestamp + ", duration="
			+ duration + ", jabberId=" + jabberId + ", avatarHash=" + avatarHash + "]";
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode()
	{
		final int prime = 31;
		int result = 1;
		result = prime * result + ((admin == null) ? 0 : admin.hashCode());
		result = prime * result + ((avatarHash == null) ? 0 : avatarHash.hashCode());
		result = prime * result + (int) (duration ^ (duration >>> 32));
		result = prime * result + ((enteredTimestamp == null) ? 0 : enteredTimestamp.hashCode());
		result = prime * result + ((id == null) ? 0 : id.hashCode());
		result = prime * result + ((jabberId == null) ? 0 : jabberId.hashCode());
		result = prime * result + ((listening == null) ? 0 : listening.hashCode());
		result = prime * result + ((muted == null) ? 0 : muted.hashCode());
		result = prime * result + ((name == null) ? 0 : name.hashCode());
		result = prime * result + ((number == null) ? 0 : number.hashCode());
		result = prime * result + ((roomId == null) ? 0 : roomId.hashCode());
		result = prime * result + ((state == null) ? 0 : state.hashCode());
		result = prime * result + ((talking == null) ? 0 : talking.hashCode());
		result = prime * result + ((wantToSpeak == null) ? 0 : wantToSpeak.hashCode());
		return result;
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj)
	{
		if (this == obj) return true;
		if (obj == null) return false;
		if (getClass() != obj.getClass()) return false;
		ConferenceCall other = (ConferenceCall) obj;
		if (admin == null)
		{
			if (other.admin != null) return false;
		}
		else if (!admin.equals(other.admin)) return false;
		if (avatarHash == null)
		{
			if (other.avatarHash != null) return false;
		}
		else if (!avatarHash.equals(other.avatarHash)) return false;
		if (duration != other.duration) return false;
		if (enteredTimestamp == null)
		{
			if (other.enteredTimestamp != null) return false;
		}
		else if (!enteredTimestamp.equals(other.enteredTimestamp)) return false;
		if (id == null)
		{
			if (other.id != null) return false;
		}
		else if (!id.equals(other.id)) return false;
		if (jabberId == null)
		{
			if (other.jabberId != null) return false;
		}
		else if (!jabberId.equals(other.jabberId)) return false;
		if (listening == null)
		{
			if (other.listening != null) return false;
		}
		else if (!listening.equals(other.listening)) return false;
		if (muted == null)
		{
			if (other.muted != null) return false;
		}
		else if (!muted.equals(other.muted)) return false;
		if (name == null)
		{
			if (other.name != null) return false;
		}
		else if (!name.equals(other.name)) return false;
		if (number == null)
		{
			if (other.number != null) return false;
		}
		else if (!number.equals(other.number)) return false;
		if (roomId == null)
		{
			if (other.roomId != null) return false;
		}
		else if (!roomId.equals(other.roomId)) return false;
		if (state != other.state) return false;
		if (talking == null)
		{
			if (other.talking != null) return false;
		}
		else if (!talking.equals(other.talking)) return false;
		if (wantToSpeak == null)
		{
			if (other.wantToSpeak != null) return false;
		}
		else if (!wantToSpeak.equals(other.wantToSpeak)) return false;
		return true;
	}
}
