package de.starface.integration.uci.java.v30.types;

import java.io.Serializable;

import de.starface.com.rpc.annotation.RpcValue;
import de.starface.com.rpc.annotation.RpcValueObject;
import de.starface.integration.uci.java.v30.messages.requests.UciFunctionKeyRequests;

/**
 * This object holds the properties of the contact info as returned by
 * {@link UciFunctionKeyRequests#getCallInfoForKey(String)}
 * 
 * @author tilmann
 */
@RpcValueObject
public class ContactInfo implements Serializable
{
	private static final long serialVersionUID = 1L;
	
	/** The first name of the contact */
	@RpcValue
	private String firstName = "";
	
	/** The family name of the contact */
	@RpcValue
	private String familyName = "";
	
	/** The company of the contact */
	@RpcValue
	private String company = "";
	
	/** The job title of the contact */
	@RpcValue
	private String jobTitle = "";
	
	/** The internal phone number of the contact */
	@RpcValue
	private String internalPhone = "";
	
	/** The office phone number of the contact */
	@RpcValue
	private String phone = "";
	
	/** The mobile phone number of the contact */
	@RpcValue
	private String mobilePhone = "";
	
	/** The private home phone number of the contact */
	@RpcValue
	private String homePhone = "";
	
	/** The second phone number of the contact */
	@RpcValue
	private String phone2 = "";
	
	/** The facsimile number of the contact */
	@RpcValue
	private String fax = "";
	
	/** The email address of the contact */
	@RpcValue
	private String eMail = "";
	
	/** The jabber id of the contact */
	@RpcValue
	private String jabberId = "";
	
	/** The street and house number of the contact */
	@RpcValue
	private String street = "";
	
	/** The post code of the contact */
	@RpcValue
	private String postCode = "";
	
	/** The city of the contact */
	@RpcValue
	private String city = "";
	
	/** The country of the contact */
	@RpcValue
	private String country = "";
	
	public String getFirstName()
	{
		return firstName;
	}
	
	public void setFirstName(String firstName)
	{
		this.firstName = firstName;
	}
	
	public String getFamilyName()
	{
		return familyName;
	}
	
	public void setFamilyName(String familyName)
	{
		this.familyName = familyName;
	}
	
	public String getCompany()
	{
		return company;
	}
	
	public void setCompany(String company)
	{
		this.company = company;
	}
	
	public String getJobTitle()
	{
		return jobTitle;
	}
	
	public void setJobTitle(String jobTitle)
	{
		this.jobTitle = jobTitle;
	}
	
	public String getMobilePhone()
	{
		return mobilePhone;
	}
	
	public void setMobilePhone(String mobilePhone)
	{
		this.mobilePhone = mobilePhone;
	}
	
	public String getHomePhone()
	{
		return homePhone;
	}
	
	public void setHomePhone(String homePhone)
	{
		this.homePhone = homePhone;
	}
	
	public String getEmail()
	{
		return eMail;
	}
	
	public void setEmail(String eMail)
	{
		this.eMail = eMail;
	}
	
	public String getJabberId()
	{
		return jabberId;
	}
	
	public void setJabberId(String jabberId)
	{
		this.jabberId = jabberId;
	}
	
	public String getStreet()
	{
		return street;
	}
	
	public void setStreet(String street)
	{
		this.street = street;
	}
	
	public String getPostCode()
	{
		return postCode;
	}
	
	public void setPostCode(String postCode)
	{
		this.postCode = postCode;
	}
	
	public String getCity()
	{
		return city;
	}
	
	public void setCity(String city)
	{
		this.city = city;
	}
	
	public String getCountry()
	{
		return country;
	}
	
	public void setCountry(String country)
	{
		this.country = country;
	}
	
	public String getInternalPhone()
	{
		return internalPhone;
	}
	
	public void setInternalPhone(String internalPhone)
	{
		this.internalPhone = internalPhone;
	}
	
	public String getPhone()
	{
		return phone;
	}
	
	public void setPhone(String phone)
	{
		this.phone = phone;
	}
	
	public String getPhone2()
	{
		return phone2;
	}
	
	public void setPhone2(String phone2)
	{
		this.phone2 = phone2;
	}
	
	public String getFax()
	{
		return fax;
	}
	
	public void setFax(String fax)
	{
		this.fax = fax;
	}
	
	@Override
	public String toString()
	{
		return "ContactInfo [firstName=" + firstName + ", familyName=" + familyName + ", company="
			+ company + ", jobTitle=" + jobTitle + ", internalPhone=" + internalPhone + ", phone="
			+ phone + ", mobilePhone=" + mobilePhone + ", homePhone=" + homePhone + ", phone2="
			+ phone2 + ", fax=" + fax + ", eMail=" + eMail + ", jabberId=" + jabberId + ", street="
			+ street + ", postCode=" + postCode + ", city=" + city + ", country=" + country + "]";
	}
	
	@Override
	public int hashCode()
	{
		final int prime = 31;
		int result = 1;
		result = prime * result + ((city == null) ? 0 : city.hashCode());
		result = prime * result + ((company == null) ? 0 : company.hashCode());
		result = prime * result + ((country == null) ? 0 : country.hashCode());
		result = prime * result + ((eMail == null) ? 0 : eMail.hashCode());
		result = prime * result + ((familyName == null) ? 0 : familyName.hashCode());
		result = prime * result + ((fax == null) ? 0 : fax.hashCode());
		result = prime * result + ((firstName == null) ? 0 : firstName.hashCode());
		result = prime * result + ((homePhone == null) ? 0 : homePhone.hashCode());
		result = prime * result + ((internalPhone == null) ? 0 : internalPhone.hashCode());
		result = prime * result + ((jabberId == null) ? 0 : jabberId.hashCode());
		result = prime * result + ((jobTitle == null) ? 0 : jobTitle.hashCode());
		result = prime * result + ((mobilePhone == null) ? 0 : mobilePhone.hashCode());
		result = prime * result + ((phone == null) ? 0 : phone.hashCode());
		result = prime * result + ((phone2 == null) ? 0 : phone2.hashCode());
		result = prime * result + ((postCode == null) ? 0 : postCode.hashCode());
		result = prime * result + ((street == null) ? 0 : street.hashCode());
		return result;
	}
	
	@Override
	public boolean equals(Object obj)
	{
		if (this == obj) return true;
		if (obj == null) return false;
		if (getClass() != obj.getClass()) return false;
		ContactInfo other = (ContactInfo) obj;
		if (city == null)
		{
			if (other.city != null) return false;
		}
		else if (!city.equals(other.city)) return false;
		if (company == null)
		{
			if (other.company != null) return false;
		}
		else if (!company.equals(other.company)) return false;
		if (country == null)
		{
			if (other.country != null) return false;
		}
		else if (!country.equals(other.country)) return false;
		if (eMail == null)
		{
			if (other.eMail != null) return false;
		}
		else if (!eMail.equals(other.eMail)) return false;
		if (familyName == null)
		{
			if (other.familyName != null) return false;
		}
		else if (!familyName.equals(other.familyName)) return false;
		if (fax == null)
		{
			if (other.fax != null) return false;
		}
		else if (!fax.equals(other.fax)) return false;
		if (firstName == null)
		{
			if (other.firstName != null) return false;
		}
		else if (!firstName.equals(other.firstName)) return false;
		if (homePhone == null)
		{
			if (other.homePhone != null) return false;
		}
		else if (!homePhone.equals(other.homePhone)) return false;
		if (internalPhone == null)
		{
			if (other.internalPhone != null) return false;
		}
		else if (!internalPhone.equals(other.internalPhone)) return false;
		if (jabberId == null)
		{
			if (other.jabberId != null) return false;
		}
		else if (!jabberId.equals(other.jabberId)) return false;
		if (jobTitle == null)
		{
			if (other.jobTitle != null) return false;
		}
		else if (!jobTitle.equals(other.jobTitle)) return false;
		if (mobilePhone == null)
		{
			if (other.mobilePhone != null) return false;
		}
		else if (!mobilePhone.equals(other.mobilePhone)) return false;
		if (phone == null)
		{
			if (other.phone != null) return false;
		}
		else if (!phone.equals(other.phone)) return false;
		if (phone2 == null)
		{
			if (other.phone2 != null) return false;
		}
		else if (!phone2.equals(other.phone2)) return false;
		if (postCode == null)
		{
			if (other.postCode != null) return false;
		}
		else if (!postCode.equals(other.postCode)) return false;
		if (street == null)
		{
			if (other.street != null) return false;
		}
		else if (!street.equals(other.street)) return false;
		return true;
	}
}
