/*
 * $Id: VoicemailListEntryProperties.java 482 2011-01-25 15:21:54Z tilmann $
 * 
 * Copyright (C) by Vertico Software GmbH, Karlsruhe, Germany. All rights reserved.
 * 
 * NOTICE: THIS MATERIAL IS CONSIDERED A TRADE SECRET BY VERTICO SOFTWARE. UNAUTHORIZED ACCESS, USE,
 * REPRODUCTION OR DISTRIBUTION IS PROHIBITED.
 * 
 * created on 06.08.2009 by tilmann
 * 
 * $HeadURL:
 * http://192.168.2.8/repos/eai-uci/java/trunk/ucp/src/de/vertico/starface/integration/uci/
 * v21/VoicemailListEntryProperties.java $
 * 
 * $LastChangedDate: 2011-01-25 16:21:54 +0100 (Di, 25 Jan 2011) $ $LastChangedBy: tilmann $
 * $LastChangedRevision: 482 $
 */
package de.starface.integration.uci.java.v30.types;

import java.io.Serializable;
import java.util.Date;

import de.starface.com.rpc.annotation.RpcValue;
import de.starface.com.rpc.annotation.RpcValueObject;
import de.starface.integration.uci.java.v30.messages.requests.UciMonitorListRequests;
import de.starface.integration.uci.java.v30.values.MonitorListEntryProperties;
import de.starface.integration.uci.java.v30.values.OrderDirection;

/**
 * This object holds the properties of the monitor list entries as returned by
 * {@link UciMonitorListRequests#getMonitorList(Date, Date, MonitorListEntryProperties, OrderDirection, int, int)}
 * 
 * @author tilmann
 */
@RpcValueObject
public class MonitorListEntry implements Serializable
{
	private static final long serialVersionUID = 1L;
	
	/** The id of the monitor list entry */
	@RpcValue
	private String id;
	
	/** The id of the corresponding CDR entry */
	@RpcValue
	private String cdrId;

	/** CallerCallerID, if known */
	@RpcValue
	private String callercallerid;
	
	/** CalledCallerID, if known */
	@RpcValue
	private String calledcallerid;
	
	/** Callbacknumber, if known */
	@RpcValue
	private String callbacknumber;
	
	/** The file of the monitor as {@link String}. */
	@RpcValue
	private String file;
	
	/**
	 * The start time of the monitor. Per default dates will be ordered newest first
	 */
	@RpcValue
	private Date monitortimestart;
	
	/**
	 * The end time of the monitor as {@link java.util.Date}. Per default dates will be ordered
	 * newest first
	 */
	@RpcValue
	private Date monitortimeend;
	
	/** The duration of the monitor in milliseconds */
	@RpcValue
	private long duration;
	
	/**
	 * @return the id
	 */
	public String getId()
	{
		return id;
	}
	
	/**
	 * @param id
	 *        the id to set
	 */
	public void setId(String id)
	{
		this.id = id;
	}
	
	/**
	 * @return the callercallerid
	 */
	public String getCallercallerid()
	{
		return callercallerid;
	}
	
	/**
	 * @param callercallerid
	 *        the callercallerid to set
	 */
	public void setCallercallerid(String callercallerid)
	{
		this.callercallerid = callercallerid;
	}
	
	/**
	 * @return the calledcallerid
	 */
	public String getCalledcallerid()
	{
		return calledcallerid;
	}
	
	/**
	 * @param calledcallerid
	 *        the calledcallerid to set
	 */
	public void setCalledcallerid(String calledcallerid)
	{
		this.calledcallerid = calledcallerid;
	}
	
	/**
	 * @return the callbacknumber
	 */
	public String getCallbacknumber()
	{
		return callbacknumber;
	}
	
	/**
	 * @param callbacknumber
	 *        the callbacknumber to set
	 */
	public void setCallbacknumber(String callbacknumber)
	{
		this.callbacknumber = callbacknumber;
	}
	
	/**
	 * @return the file
	 */
	public String getFile()
	{
		return file;
	}
	
	/**
	 * @param file
	 *        the file to set
	 */
	public void setFile(String file)
	{
		this.file = file;
	}
	
	/**
	 * @return the monitortimestart
	 */
	public Date getMonitortimestart()
	{
		return monitortimestart;
	}
	
	/**
	 * @param monitortimestart
	 *        the monitortimestart to set
	 */
	public void setMonitortimestart(Date monitortimestart)
	{
		this.monitortimestart = monitortimestart;
	}
	
	/**
	 * @return the monitortimeend
	 */
	public Date getMonitortimeend()
	{
		return monitortimeend;
	}
	
	/**
	 * @param monitortimeend
	 *        the monitortimeend to set
	 */
	public void setMonitortimeend(Date monitortimeend)
	{
		this.monitortimeend = monitortimeend;
	}
	
	/**
	 * @return the duration
	 */
	public long getDuration()
	{
		return duration;
	}
	
	/**
	 * @param duration
	 *        the duration to set
	 */
	public void setDuration(long duration)
	{
		this.duration = duration;
	}
	
	/**
	 * @return Returns the cdrId.
	 */
	public String getCdrId()
	{
		return cdrId;
	}
	
	/**
	 * @param cdrId
	 *        The cdrId to set.
	 */
	public void setCdrId(String cdrId)
	{
		this.cdrId = cdrId;
	}
	
	/**
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode()
	{
		final int prime = 31;
		int result = 1;
		result = prime * result + ((callbacknumber == null) ? 0 : callbacknumber.hashCode());
		result = prime * result + ((calledcallerid == null) ? 0 : calledcallerid.hashCode());
		result = prime * result + ((callercallerid == null) ? 0 : callercallerid.hashCode());
		result = prime * result + ((cdrId == null) ? 0 : cdrId.hashCode());
		result = prime * result + (int) (duration ^ (duration >>> 32));
		result = prime * result + ((file == null) ? 0 : file.hashCode());
		result = prime * result + ((id == null) ? 0 : id.hashCode());
		result = prime * result + ((monitortimeend == null) ? 0 : monitortimeend.hashCode());
		result = prime * result + ((monitortimestart == null) ? 0 : monitortimestart.hashCode());
		return result;
	}
	
	/**
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj)
	{
		if (this == obj) return true;
		if (obj == null) return false;
		if (getClass() != obj.getClass()) return false;
		MonitorListEntry other = (MonitorListEntry) obj;
		if (callbacknumber == null)
		{
			if (other.callbacknumber != null) return false;
		}
		else if (!callbacknumber.equals(other.callbacknumber)) return false;
		if (calledcallerid == null)
		{
			if (other.calledcallerid != null) return false;
		}
		else if (!calledcallerid.equals(other.calledcallerid)) return false;
		if (callercallerid == null)
		{
			if (other.callercallerid != null) return false;
		}
		else if (!callercallerid.equals(other.callercallerid)) return false;
		if (cdrId == null)
		{
			if (other.cdrId != null) return false;
		}
		else if (!cdrId.equals(other.cdrId)) return false;
		if (duration != other.duration) return false;
		if (file == null)
		{
			if (other.file != null) return false;
		}
		else if (!file.equals(other.file)) return false;
		if (id == null)
		{
			if (other.id != null) return false;
		}
		else if (!id.equals(other.id)) return false;
		if (monitortimeend == null)
		{
			if (other.monitortimeend != null) return false;
		}
		else if (!monitortimeend.equals(other.monitortimeend)) return false;
		if (monitortimestart == null)
		{
			if (other.monitortimestart != null) return false;
		}
		else if (!monitortimestart.equals(other.monitortimestart)) return false;
		return true;
	}
	
	/**
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString()
	{
		return "MonitorListEntry [id=" + id + ", cdrId=" + cdrId + ", callercallerid=" + callercallerid
			+ ", calledcallerid=" + calledcallerid + ", callbacknumber=" + callbacknumber + ", file=" + file
			+ ", monitortimestart=" + monitortimestart + ", monitortimeend=" + monitortimeend + ", duration="
			+ duration + "]";
	}
	
}
