package de.starface.integration.uci.java.v30.types;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

import de.starface.com.rpc.annotation.RpcValue;
import de.starface.com.rpc.annotation.RpcValueObject;
import de.starface.integration.uci.java.v30.values.QueueCallState;

/**
 * Represents the Information about the call(er)
 * 
 * @author mphilippi
 * 
 */
@RpcValueObject
public class UciQueueCall implements Serializable
{
	private static final long serialVersionUID = -9109094888101805111L;
	/**
	 * The Id of the Call which is unique but not unchangeable.
	 */
	@RpcValue
	String callId;
	
	/**
	 * The name of the caller if known.
	 */
	@RpcValue
	String callerName;
	
	/**
	 * The number of the caller if known.
	 */
	@RpcValue
	String callerNumber;
	
	/**
	 * The accountid of the queue
	 */
	@RpcValue
	Integer queueAccountId;
	
	/**
	 * The priority of the caller
	 */
	@RpcValue
	Integer priority;
	
	/**
	 * The state of the call (waiting, ringing, connected, exited)
	 */
	@RpcValue
	QueueCallState state;
	
	/**
	 * An UTC timestamp that defines when the call entered the queue
	 */
	@RpcValue
	Date incommingTime;
	
	/**
	 * An UTC timestamp that defines when the call was answered the first time by an agent
	 */
	@RpcValue
	Date connectedTime;
	
	/**
	 * The agents that are currently associated (ringing, connected) with this call.
	 */
	@RpcValue
	List<Integer> agents;
	
	/**
	 * The unique id of the caller leg.
	 */
	@RpcValue
	String callerLegUuid;
	
	/**
	 * The position of the caller.
	 */
	@RpcValue
	int position;
	
	/**
	 * @return Returns the Id of the Call which is unique but not unchangeable.
	 */
	public String getCallId()
	{
		return callId;
	}
	
	/**
	 * @return Returns the priority of the caller
	 */
	public Integer getPriority()
	{
		return priority;
	}
	
	/**
	 * @param priority
	 *        The priority of the caller
	 */
	public void setPriority(Integer priority)
	{
		this.priority = priority;
	}
	
	/**
	 * @return Returns the accountid of the queue
	 */
	public Integer getQueueAccountId()
	{
		return queueAccountId;
	}
	
	/**
	 * @param queueId
	 *        The accountid of the queue
	 */
	public void setQueueAccountId(Integer queueId)
	{
		this.queueAccountId = queueId;
	}
	
	/**
	 * @return Returns the state.
	 */
	public QueueCallState getState()
	{
		return state;
	}
	
	/**
	 * @param state
	 *        The state to set.
	 */
	public void setState(QueueCallState state)
	{
		this.state = state;
	}
	
	/**
	 * @return Returns the agents that are currently associated (ringing, connected) with this call.
	 */
	public List<Integer> getAgents()
	{
		return agents;
	}
	
	/**
	 * @param agents
	 *        The agents that are currently associated (ringing, connected) with this call.
	 */
	public void setAgents(List<Integer> agents)
	{
		this.agents = agents;
	}
	
	public UciQueueCall()
	{
		super();
	}
	
	/**
	 * 
	 */
	public UciQueueCall(String callId, String callerName, String callerNumber, Date incomingTimestamp,
						Integer queueId, Integer priority, QueueCallState state, List<Integer> agents,
						String callerLegId, int position)
	{
		super();
		this.callId = callId;
		this.callerName = callerName;
		this.callerNumber = callerNumber;
		this.incommingTime = incomingTimestamp;
		this.queueAccountId = queueId;
		this.priority = priority;
		this.state = state;
		this.agents = agents;
		this.connectedTime = new Date(0);
		this.callerLegUuid = callerLegId;
		this.position = position;
	}
	
	/**
	 * @return Returns the name of the caller if known.
	 */
	public String getCallerName()
	{
		return callerName;
	}
	
	/**
	 * @param callerName
	 *        The name of the caller if known.
	 */
	public void setCallerName(String callerName)
	{
		this.callerName = callerName;
	}
	
	/**
	 * @return Returns the number of the caller if known.
	 */
	public String getCallerNumber()
	{
		return callerNumber;
	}
	
	/**
	 * @param callerNumber
	 *        The number of the caller if known.
	 */
	public void setCallerNumber(String callerNumber)
	{
		this.callerNumber = callerNumber;
	}
	
	/**
	 * @return Returns an UTC timestamp that defines when the call entered the queue
	 */
	public Date getIncommingTime()
	{
		return incommingTime;
	}
	
	/**
	 * @param incommingTime
	 *        An UTC timestamp that defines when the call entered the queue
	 */
	public void setIncommingTime(Date incommingTime)
	{
		this.incommingTime = incommingTime;
	}
	
	/**
	 * @return Returns an UTC timestamp that defines when the call was answered the first time by an
	 *         agent
	 */
	public Date getConnectedTime()
	{
		return connectedTime;
	}
	
	/**
	 * @param connectedTime
	 *        An UTC timestamp that defines when the call was answered the first time by an agent
	 */
	public void setConnectedTime(Date connectedTime)
	{
		this.connectedTime = connectedTime;
	}
	
	/**
	 * @param callId
	 *        The Id of the Call which is unique but not unchangeable.
	 */
	public void setCallId(String callId)
	{
		this.callId = callId;
	}
	
	/**
	 * @return the callerLegUuid
	 */
	public String getCallerLegUuid()
	{
		return callerLegUuid;
	}
	
	/**
	 * @param callerLegUuid
	 *        the callerLegUuid to set
	 */
	public void setCallerLegUuid(String callerLegUuid)
	{
		this.callerLegUuid = callerLegUuid;
	}
	
	/**
	 * @return the position
	 */
	public int getPosition()
	{
		return position;
	}
	
	/**
	 * @param position
	 *        the position to set
	 */
	public void setPosition(int position)
	{
		this.position = position;
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode()
	{
		final int prime = 31;
		int result = 1;
		result = prime * result + ((agents == null) ? 0 : agents.hashCode());
		result = prime * result + ((callId == null) ? 0 : callId.hashCode());
		result = prime * result + ((callerLegUuid == null) ? 0 : callerLegUuid.hashCode());
		result = prime * result + ((callerName == null) ? 0 : callerName.hashCode());
		result = prime * result + ((callerNumber == null) ? 0 : callerNumber.hashCode());
		result = prime * result + ((connectedTime == null) ? 0 : connectedTime.hashCode());
		result = prime * result + ((incommingTime == null) ? 0 : incommingTime.hashCode());
		result = prime * result + ((priority == null) ? 0 : priority.hashCode());
		result = prime * result + ((queueAccountId == null) ? 0 : queueAccountId.hashCode());
		result = prime * result + ((state == null) ? 0 : state.hashCode());
		return result;
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj)
	{
		if (this == obj) return true;
		if (obj == null) return false;
		if (getClass() != obj.getClass()) return false;
		UciQueueCall other = (UciQueueCall) obj;
		if (agents == null)
		{
			if (other.agents != null) return false;
		}
		else if (!agents.equals(other.agents)) return false;
		if (callId == null)
		{
			if (other.callId != null) return false;
		}
		else if (!callId.equals(other.callId)) return false;
		if (callerLegUuid == null)
		{
			if (other.callerLegUuid != null) return false;
		}
		else if (!callerLegUuid.equals(other.callerLegUuid)) return false;
		if (callerName == null)
		{
			if (other.callerName != null) return false;
		}
		else if (!callerName.equals(other.callerName)) return false;
		if (callerNumber == null)
		{
			if (other.callerNumber != null) return false;
		}
		else if (!callerNumber.equals(other.callerNumber)) return false;
		if (connectedTime == null)
		{
			if (other.connectedTime != null) return false;
		}
		else if (!connectedTime.equals(other.connectedTime)) return false;
		if (incommingTime == null)
		{
			if (other.incommingTime != null) return false;
		}
		else if (!incommingTime.equals(other.incommingTime)) return false;
		if (priority == null)
		{
			if (other.priority != null) return false;
		}
		else if (!priority.equals(other.priority)) return false;
		if (queueAccountId == null)
		{
			if (other.queueAccountId != null) return false;
		}
		else if (!queueAccountId.equals(other.queueAccountId)) return false;
		if (state != other.state) return false;
		return true;
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString()
	{
		return "UciQueueCall [callId=" + callId + ", callerName=" + callerName + ", callerNumber=" + callerNumber
			+ ", queueAccountId=" + queueAccountId + ", priority=" + priority + ", state=" + state
			+ ", incommingTime=" + incommingTime + ", connectedTime=" + connectedTime + ", agents=" + agents
			+ ", callerLegUuid=" + callerLegUuid + "]";
	}
	
}
