/*
 * $Id: VoicemailListEntryProperties.java 482 2011-01-25 15:21:54Z tilmann $
 * 
 * Copyright (C) by Vertico Software GmbH, Karlsruhe, Germany. All rights reserved.
 * 
 * NOTICE: THIS MATERIAL IS CONSIDERED A TRADE SECRET BY VERTICO SOFTWARE. UNAUTHORIZED ACCESS, USE,
 * REPRODUCTION OR DISTRIBUTION IS PROHIBITED.
 * 
 * created on 06.08.2009 by tilmann
 * 
 * $HeadURL:
 * http://192.168.2.8/repos/eai-uci/java/trunk/ucp/src/de/vertico/starface/integration/uci/
 * v21/VoicemailListEntryProperties.java $
 * 
 * $LastChangedDate: 2011-01-25 16:21:54 +0100 (Di, 25 Jan 2011) $ $LastChangedBy: tilmann $
 * $LastChangedRevision: 482 $
 */
package de.starface.integration.uci.java.v30.types;

import java.io.Serializable;
import java.util.Date;

import de.starface.com.rpc.annotation.RpcValue;
import de.starface.com.rpc.annotation.RpcValueObject;
import de.starface.integration.uci.java.v30.messages.requests.UciVoicemailListRequests;
import de.starface.integration.uci.java.v30.values.OrderDirection;
import de.starface.integration.uci.java.v30.values.VoicemailListEntryFolder;
import de.starface.integration.uci.java.v30.values.VoicemailListEntryProperties;

/**
 * This object holds the properties of the voicemail list entries as returned by
 * {@link UciVoicemailListRequests#getVoicemailList(Date, Date, String, VoicemailListEntryFolder, VoicemailListEntryProperties, OrderDirection, int, int)}
 * 
 * @author tilmann
 */
@RpcValueObject
public class VoicemailListEntry implements Serializable
{
	private static final long serialVersionUID = 1L;
	
	/** The id of the voicemail list entry */
	@RpcValue
	private String id;
	
	/** The id of the corresponding CDR entry */
	@RpcValue
	private String cdrId;

	/** The id of the mailbox of the voicemail */
	@RpcValue
	private String mailboxId;
	
	/** The display name of the mailbox of the voicemail */
	@RpcValue
	private String mailboxName;
	
	/**
	 * The folder the voicemail belongs to holding one of the values defined in
	 * {@link VoicemailListEntryFolder}.
	 */
	@RpcValue
	private VoicemailListEntryFolder folder;
	
	/** The number that was called, if known */
	@RpcValue
	private String calledNumber;
	
	/** The number of the caller, if known */
	@RpcValue
	private String callerNumber;
	
	/** A description of the call (usually the CLIP), if known */
	@RpcValue
	private String callDescription;
	
	/**
	 * The start time of the call. Per default dates will be ordered newest first
	 */
	@RpcValue
	private Date startTime;
	
	/** The duration of the call in seconds */
	@RpcValue
	private int duration;
	
	/**
	 * The name of the group if this voicemail was received by a group (the empty string otherwise)
	 */
	@RpcValue(minVersion = 22)
	private String groupId = "";
	
	public String getId()
	{
		return id;
	}
	
	public void setId(String id)
	{
		this.id = id;
	}
	
	public String getMailboxId()
	{
		return mailboxId;
	}
	
	public void setMailboxId(String mailboxId)
	{
		this.mailboxId = mailboxId;
	}
	
	public String getMailboxName()
	{
		return mailboxName;
	}
	
	public void setMailboxName(String mailboxName)
	{
		this.mailboxName = mailboxName;
	}
	
	public VoicemailListEntryFolder getFolder()
	{
		return folder;
	}
	
	public void setFolder(VoicemailListEntryFolder folder)
	{
		this.folder = folder;
	}
	
	public String getCalledNumber()
	{
		return calledNumber;
	}
	
	public void setCalledNumber(String calledNumber)
	{
		this.calledNumber = calledNumber;
	}
	
	public String getCallerNumber()
	{
		return callerNumber;
	}
	
	public void setCallerNumber(String callerNumber)
	{
		this.callerNumber = callerNumber;
	}
	
	public String getCallDescription()
	{
		return callDescription;
	}
	
	public void setCallDescription(String callDescription)
	{
		this.callDescription = callDescription;
	}
	
	public Date getStartTime()
	{
		return startTime;
	}
	
	public void setStartTime(Date startTime)
	{
		this.startTime = startTime;
	}
	
	public int getDuration()
	{
		return duration;
	}
	
	public void setDuration(int duration)
	{
		this.duration = duration;
	}
	
	public String getGroupId()
	{
		return groupId;
	}
	
	public void setGroupId(String groupId)
	{
		this.groupId = groupId;
	}
	
	public boolean isGroupCall()
	{
		return groupId != null && !"".equals(groupId);
	}
	
	public String getCdrId()
	{
		return cdrId;
	}
	
	public void setCdrId(String cdrId)
	{
		this.cdrId = cdrId;
	}
	
	/**
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString()
	{
		return "VoicemailListEntry [id=" + id + ", cdrId=" + cdrId + ", mailboxId=" + mailboxId + ", mailboxName="
			+ mailboxName + ", folder=" + folder + ", calledNumber=" + calledNumber + ", callerNumber="
			+ callerNumber + ", callDescription=" + callDescription + ", startTime=" + startTime + ", duration="
			+ duration + ", groupId=" + groupId + "]";
	}
	
	/**
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode()
	{
		final int prime = 31;
		int result = 1;
		result = prime * result + ((callDescription == null) ? 0 : callDescription.hashCode());
		result = prime * result + ((calledNumber == null) ? 0 : calledNumber.hashCode());
		result = prime * result + ((callerNumber == null) ? 0 : callerNumber.hashCode());
		result = prime * result + ((cdrId == null) ? 0 : cdrId.hashCode());
		result = prime * result + duration;
		result = prime * result + ((folder == null) ? 0 : folder.hashCode());
		result = prime * result + ((groupId == null) ? 0 : groupId.hashCode());
		result = prime * result + ((id == null) ? 0 : id.hashCode());
		result = prime * result + ((mailboxId == null) ? 0 : mailboxId.hashCode());
		result = prime * result + ((mailboxName == null) ? 0 : mailboxName.hashCode());
		result = prime * result + ((startTime == null) ? 0 : startTime.hashCode());
		return result;
	}
	
	/**
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj)
	{
		if (this == obj) return true;
		if (obj == null) return false;
		if (getClass() != obj.getClass()) return false;
		VoicemailListEntry other = (VoicemailListEntry) obj;
		if (callDescription == null)
		{
			if (other.callDescription != null) return false;
		}
		else if (!callDescription.equals(other.callDescription)) return false;
		if (calledNumber == null)
		{
			if (other.calledNumber != null) return false;
		}
		else if (!calledNumber.equals(other.calledNumber)) return false;
		if (callerNumber == null)
		{
			if (other.callerNumber != null) return false;
		}
		else if (!callerNumber.equals(other.callerNumber)) return false;
		if (cdrId == null)
		{
			if (other.cdrId != null) return false;
		}
		else if (!cdrId.equals(other.cdrId)) return false;
		if (duration != other.duration) return false;
		if (folder != other.folder) return false;
		if (groupId == null)
		{
			if (other.groupId != null) return false;
		}
		else if (!groupId.equals(other.groupId)) return false;
		if (id == null)
		{
			if (other.id != null) return false;
		}
		else if (!id.equals(other.id)) return false;
		if (mailboxId == null)
		{
			if (other.mailboxId != null) return false;
		}
		else if (!mailboxId.equals(other.mailboxId)) return false;
		if (mailboxName == null)
		{
			if (other.mailboxName != null) return false;
		}
		else if (!mailboxName.equals(other.mailboxName)) return false;
		if (startTime == null)
		{
			if (other.startTime != null) return false;
		}
		else if (startTime.compareTo(other.startTime) != 0) return false;
		return true;
	}
	
}
