/*
 * $Id: UcpCallEvents.java 794 2013-08-08 15:17:10Z dirk $
 * 
 * Copyright (C) by Vertico Software GmbH, Karlsruhe, Germany. All rights reserved.
 * 
 * NOTICE: THIS MATERIAL IS CONSIDERED A TRADE SECRET BY VERTICO SOFTWARE. UNAUTHORIZED ACCESS, USE,
 * REPRODUCTION OR DISTRIBUTION IS PROHIBITED.
 * 
 * created on 06.08.2009 by tilmann
 * 
 * $HeadURL:
 * http://192.168.2.8/repos/eai-uci/java/trunk/ucp/src/de/vertico/starface/integration/uci/
 * ucp/v21/client/UcpClientCommunicationCall.java $
 * 
 * $LastChangedDate: 2013-08-08 17:17:10 +0200 (Do, 08. Aug 2013) $ $LastChangedBy: dirk $
 * $LastChangedRevision: 794 $
 */
package de.starface.integration.uci.java.v30.ucp.messages.events;

import java.util.Map;

import de.starface.com.rpc.annotation.RpcAsynchronous;
import de.starface.com.rpc.annotation.RpcInterface;
import de.starface.integration.uci.java.v30.UciService;
import de.starface.integration.uci.java.v30.types.CcbsAccount;
import de.starface.integration.uci.java.v30.values.CcbsAccountProperties;
import de.starface.integration.uci.java.v30.values.CcbsCallProperties;

/**
 * This interface defines the call events that can be received by a UCI client implementation in
 * order to handle phone calls.
 * 
 * @author tilmann
 */
@RpcInterface(UcpCcbsEvents.SERVICE_NAME)
@UciService(UcpCcbsEvents.SERVICE_NAME)
public interface UcpCcbsEvents
{
	
	/** The UCI service name used for this interface */
	public static final String SERVICE_NAME = "ucp.v30.events.ccbscall";
	
	/**
	 * The ReceiveCcbsState event provides a number of properties about the call the state is
	 * changing of. The information provided in the map is defined by its properties as seen in
	 * {@link CcbsCallProperties}. If a name or number is not known to STARFACE an empty string is
	 * committed for that property. It is possible that information about the caller or the called
	 * person gets available in the middle of a series of events so that the first call state events
	 * don’t provide any details but later events contain full participant information. The
	 * sequential change of the {@link CcbsCallProperties#ccbsCallState} property adheres to the
	 * state diagram given in the UCI specification.
	 * 
	 * @param ccbsCallProperties
	 *        the different properties of the call in a {@link Map}. The constants of
	 *        {@link CcbsCallProperties} are used as keys in the map.
	 */
	@RpcAsynchronous
	public void receiveCcbsState(Map<String, Object> ccbsCallProperties);
	
	/**
	 * The ReceiveCcbsAccountState event provides a number of properties about the account the state
	 * is changing of. The information provided in the map is defined by its properties as seen in
	 * {@link CcbsAccountProperties}. If a name or number is not known to STARFACE an empty string
	 * is committed for that property. It is possible that information about the caller or the
	 * called person gets available in the middle of a series of events so that the first call state
	 * events don’t provide any details but later events contain full participant information. The
	 * sequential change of the {@link CcbsAccount#ccbsAccountState} property adheres to the state
	 * diagram given in the UCI specification.
	 * 
	 * @param ccbsAccountStateProperties
	 *        the different properties of the ccbsAccountStateProperties account.
	 */
	
	@RpcAsynchronous
	public void receiveCcbsAccountState(Map<String, Object> ccbsAccountStateProperties);
}
