package de.starface.integration.uci.java.v30.values;

import java.util.Date;
import java.util.List;
import java.util.UUID;

public enum UciQueueCallProperties
{
	/**
	 * The unique (yet changeable) id of the call
	 */
	callId(UUID.class),
	/**
	 * The name of the caller (if known)
	 */
	callerName(String.class),
	/**
	 * The number of the caller (if known)
	 */
	callerNumber(String.class),
	/**
	 * The time when the caller entered the queue (UTC)
	 */
	incommingTime(Date.class),
	/**
	 * The time when the caller got first connected to an agent (UTC)
	 */
	connectedTime(Date.class),
	/**
	 * The accountId of the queue
	 */
	queueAccountId(Integer.class),
	/**
	 * The priority of the caller
	 */
	priority(Integer.class),
	/**
	 * The state of the call as defined in {@link QueueCallState}
	 */
	state(QueueCallState.class),
	/**
	 * A list of agent-accountIds associated with this call (ringing or connected)
	 */
	agents(List.class),
	/**
	 * The number of the caller (if known)
	 */
	callerLegUuid(String.class),
	/**
	 * The priority of the caller
	 */
	position(Integer.class);
	
	private Class<?> type;
	
	private UciQueueCallProperties(Class<?> type)
	{
		this.type = type;
	}
	
	/**
	 * @return the java type of the property
	 */
	public Class<?> getType()
	{
		return type;
	}
}
