/*
 * $Id: VoicemailListEntryProperties.java 847 2013-11-20 11:18:26Z dirk $
 * 
 * Copyright (C) by Vertico Software GmbH, Karlsruhe, Germany. All rights reserved.
 * 
 * NOTICE: THIS MATERIAL IS CONSIDERED A TRADE SECRET BY VERTICO SOFTWARE. UNAUTHORIZED ACCESS, USE,
 * REPRODUCTION OR DISTRIBUTION IS PROHIBITED.
 * 
 * created on 06.08.2009 by tilmann
 * 
 * $HeadURL:
 * http://192.168.2.8/repos/eai-uci/java/trunk/ucp/src/de/vertico/starface/integration/uci/
 * v21/VoicemailListEntryProperties.java $
 * 
 * $LastChangedDate: 2013-11-20 12:18:26 +0100 (Wed, 20 Nov 2013) $ $LastChangedBy: dirk $
 * $LastChangedRevision: 847 $
 */
package de.starface.integration.uci.java.v30.values;

import java.util.Date;

import de.starface.integration.uci.java.v30.ucp.messages.requests.UcpVoicemailListRequests;

/**
 * This enum holds constants with the property names of the voicemail list entries as returned by
 * {@link UcpVoicemailListRequests#getVoicemailList(Date, Date, String, String, String, String, int, int)}
 * 
 * @author tilmann
 */
public enum VoicemailListEntryProperties
{
	/** The id of the voicemail list entry as {@link String} */
	id(OrderDirection.ASCENDING, String.class),
	
	/** The id of the mailbox of the voicemail as {@link String} */
	mailboxId(OrderDirection.ASCENDING, String.class),
	
	/** The display name of the mailbox of the voicemail as {@link String} */
	mailboxName(OrderDirection.ASCENDING, String.class),
	
	/**
	 * The folder the voicemail belongs to as {@link String} holding one of the values defined in
	 * {@link VoicemailListEntryFolder}.
	 */
	folder(OrderDirection.ASCENDING, String.class),
	
	/** The number that was called, if known as {@link String} */
	calledNumber(OrderDirection.ASCENDING, String.class),
	
	/** The number of the caller, if known as {@link String} */
	callerNumber(OrderDirection.ASCENDING, String.class),
	
	/** A description of the call (usually the CLIP), if known as {@link String} */
	callDescription(OrderDirection.ASCENDING, String.class),
	
	/**
	 * The start time of the call as {@link java.util.Date}. Per default dates will be ordered
	 * newest first
	 */
	startTime(OrderDirection.DESCENDING, Date.class),
	
	/** The duration of the call in seconds as {@link Integer} */
	duration(OrderDirection.ASCENDING, Integer.class),
	
	/**
	 * The name of the group if this voicemail was received by a group as {@link String} (the empty
	 * string otherwise)
	 */
	groupId(OrderDirection.ASCENDING, String.class);
	
	private OrderDirection defaultOrderDirection;
	
	private Class<?> type;
	
	private VoicemailListEntryProperties(OrderDirection defaultOrderDirection, Class<?> type)
	{
		this.defaultOrderDirection = defaultOrderDirection;
		this.type = type;
	}
	
	/**
	 * @return the default {@link OrderDirection} for the current property
	 */
	public OrderDirection getDefaultOrderDirection()
	{
		return defaultOrderDirection;
	}
	
	/**
	 * @return the java type of the property
	 */
	public Class<?> getType()
	{
		return type;
	}
	
}
